@@ -90,6 +90,7 @@ from neutron_lib.api.definitions import network_segment_range
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
 from neutron_lib.api.definitions import port_device_profile
+from neutron_lib.api.definitions import port_hardware_offload_type
 from neutron_lib.api.definitions import port_hint_ovs_tx_steering
 from neutron_lib.api.definitions import port_hints
 from neutron_lib.api.definitions import port_mac_address_override
@@ -131,6 +132,8 @@ from neutron_lib.api.definitions import routerservicetype
 from neutron_lib.api.definitions import security_groups_normalized_cidr
 from neutron_lib.api.definitions import security_groups_port_filtering
 from neutron_lib.api.definitions import security_groups_remote_address_group
+from neutron_lib.api.definitions import \
+    security_groups_rules_belongs_to_default_sg
 from neutron_lib.api.definitions import security_groups_shared_filtering
 from neutron_lib.api.definitions import segment
 from neutron_lib.api.definitions import segments_peer_subnet_host_routes
@@ -156,6 +159,7 @@ from neutron_lib.api.definitions import uplink_status_propagation
 from neutron_lib.api.definitions import vlan_filter
 from neutron_lib.api.definitions import vlantransparent
 from neutron_lib.api.definitions import vpn
+from neutron_lib.api.definitions import vpn_aes_ccm_gcm
 from neutron_lib.api.definitions import vpn_endpoint_groups
 from neutron_lib.api.definitions import vpn_flavors
 
@@ -241,6 +245,7 @@ _ALL_API_DEFINITIONS = {
     pagination,
     port,
     port_device_profile,
+    port_hardware_offload_type,
     port_hints,
     port_hint_ovs_tx_steering,
     port_mac_address_override,
@@ -282,6 +287,7 @@ _ALL_API_DEFINITIONS = {
     security_groups_normalized_cidr,
     security_groups_port_filtering,
     security_groups_remote_address_group,
+    security_groups_rules_belongs_to_default_sg,
     security_groups_shared_filtering,
     segment,
     segments_peer_subnet_host_routes,
@@ -307,6 +313,7 @@ _ALL_API_DEFINITIONS = {
     vlan_filter,
     vlantransparent,
     vpn,
+    vpn_aes_ccm_gcm,
     vpn_endpoint_groups,
     vpn_flavors,
 }
